@@ -27,6 +27,11 @@ sub _seconds_as_components
     return ($_[1]) x 3;
 }
 
+sub _stringify { ( $_[0]->{utc_rd_days} == DateTime::INFINITY
+                   ? DateTime::INFINITY . ''
+                   : DateTime::NEG_INFINITY . ''
+                 ) }
+
 sub STORABLE_freeze { return }
 sub STORABLE_thaw { return }
 
@@ -121,9 +126,9 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 David Rolsky.  All rights reserved.  This program
-is free software; you can redistribute it and/or modify it under the
-same terms as Perl itself.
+Copyright (c) 2003-2005 David Rolsky.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 The full text of the license can be found in the LICENSE file included
 with this module.
